==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/sr-CS/localizations.php <==
<?php

return [

    'select_language' => 'Izaberi jezik',
    'languages' => [
        'en-US'=> 'Engleski, SAD',
        'en-GB'=> 'Engleski, UK',
        'am-ET' => 'Amharski',
        'af-ZA'=> 'Afrički',
        'ar-SA'=> 'Arapski',
        'bg-BG'=> 'Bugarski',
        'zh-CN'=> 'Kineski pojednostavljen',
        'zh-TW'=> 'Kineski tradicionalan',
        'ca-ES' => 'Katalonski',
        'hr-HR'=> 'Hrvatski',
        'cs-CZ'=> 'Češki',
        'da-DK'=> 'Danski',
        'nl-NL'=> 'Holandski',
        'en-ID'=> 'Engleski, Indonezija',
        'et-EE'=> 'Estonski',
        'fil-PH'=> 'Filipinski',
        'fi-FI'=> 'Finski',
        'fr-FR'=> 'Francuski',
        'de-DE'=> 'Nemački',
        'de-if'=> 'Nemački (neformalni)',
        'el-GR'=> 'Grčki',
        'he-IL'=> 'Hebrejski',
        'hu-HU'=> 'Madjarski',
        'is-IS' => 'Islandski',
        'id-ID'=> 'Indonežanski',
        'ga-IE'=> 'Irski',
        'it-IT'=> 'Italijanski',
        'ja-JP'=> 'Japanski',
        'km-KH'=>'Kmer',
        'ko-KR'=> 'Korejski',
        'lt-LT'=>'Litvanski',
        'lv-LV'=> 'Letonski',
        'mk-MK'=> 'Makedonski',
        'ms-MY'=> 'Malajski',
        'mi-NZ'=> 'Maorski',
        'mn-MN'=> 'Mongolski',
        'no-NO'=> 'Norveški',
        'fa-IR'=> 'Persijski',
        'pl-PL'=> 'Poljski',
        'pt-PT'=> 'Portugalski',
        'pt-BR'=> 'Portugalski (Brazil)',
        'ro-RO'=> 'Rumunski',
        'ru-RU'=> 'Ruski',
        'sr-CS' => 'Srpski (Latinica)',
        'sk-SK'=> 'Slovački',
        'sl-SI'=> 'Slovenački',
        'es-ES'=> 'Španski',
        'es-CO'=> 'Španski (Kolumbija)',
        'es-MX'=> 'Španski (Meksiko)',
        'es-VE'=> 'Španski (Venecuela)',
        'sv-SE'=> 'Švedski',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamilski',
        'th-TH'=> 'Tajlandski',
        'tr-TR'=> 'Turski',
        'uk-UA'=> 'Ukrajinski',
        'vi-VN'=> 'Vijetnamski',
        'cy-GB'=> 'Velški',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Izaberite državu',
    
    'countries' => [
        'AC'=>'Asension',
        'AD'=>'Andora',
        'AE'=>'Ujedinjeni Arapski Emirati',
        'AF'=>'Afganistan',
        'AG'=>'Antigva i Barbuda',
        'AI'=>'Angvila',
        'AL'=>'Albanija',
        'AM'=>'Jermenija',
        'AN'=>'Holandski Antili',
        'AO'=>'Angola',
        'AQ'=>'Antartika',
        'AR'=>'Argentina',
        'AS'=>'Američka Samoa',
        'AT'=>'Austrija',
        'AU'=>'Australija',
        'AW'=>'Aruba',
        'AX'=>'Olandska Ostrva',
        'AZ'=>'Azerbejdžan',
        'BA'=>'Bosna i Hercegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgija',
        'BD'=>'Bangladeš',
        'BF'=>'Burkina Faso',
        'BG'=>'Bugarska',
        'BH'=>'Bahrein',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Bruneja Darusalam',
        'BO'=>'Bolivija',
        'BR'=>'Brazil',
        'BS'=>'Bahami',
        'BT'=>'Butan',
        'BV'=>'Ostrvo Buve',
        'BW'=>'Bocvana',
        'BY'=>'Belorusija',
        'BZ'=>'Beliz',
        'CA'=>'Kanada',
        'CC'=>'Kokosova (Kiling) Ostrva',
        'CD'=>'Kongo (Demokratska republika)',
        'CF'=>'Centralnoafrička Republika',
        'CG'=>'Kongo (Republika)',
        'CH'=>'Švajcarska',
        'CI'=>'Obala slonovače',
        'CK'=>'Kukova ostrva',
        'CL'=>'Čile',
        'CM'=>'Kamerun',
        'CN'=>'Narodna republika Kina',
        'CO'=>'Kolumbija',
        'CR'=>'Kostarika',
        'CU'=>'Kuba',
        'CV'=>'Zelenortska ostrva',
        'CX'=>'Božićno ostrvo',
        'CY'=>'Kipar',
        'CZ'=>'Češka republika',
        'DE'=>'Nemačka',
        'DJ'=>'Đibuti',
        'DK'=>'Danska',
        'DM'=>'Dominika',
        'DO'=>'Dominikanska republika',
        'DZ'=>'Alžir',
        'EC'=>'Ekvador',
        'EE'=>'Estonija',
        'EG'=>'Egipat',
        'ER'=>'Eritreja',
        'ES'=>'Španija',
        'ET'=>'Etiopija',
        'EU'=>'Evropska unija',
        'FI'=>'Finska',
        'FJ'=>'Fidži',
        'FK'=>'Folklanska ostrva',
        'FM'=>'Mikronezija',
        'FO'=>'Farska ostrva',
        'FR'=>'Francuska',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Gruzija',
        'GF'=>'Francuska gvajana',
        'GG'=>'Gernzi',
        'GH'=>'Gana',
        'GI'=>'Gibraltar',
        'GL'=>'Grenland',
        'GM'=>'Gambija',
        'GN'=>'Gvineja',
        'GP'=>'Gvadalupe',
        'GQ'=>'Ekvatorijalna gvineja',
        'GR'=>'Grčka',
        'GS'=>'Južna Džordžija i Južna Sendvič Ostrva',
        'GT'=>'Gvatemala',
        'GU'=>'Guam',
        'GW'=>'Gvineja Bisao',
        'GY'=>'Gvajana',
        'HK'=>'Hong Kong',
        'HM'=>'Ostrvo Herd i ostrva Makdonald',
        'HN'=>'Honduras',
        'HR'=>'Hrvatska',
        'HT'=>'Haiti',
        'HU'=>'Mađarska',
        'ID'=>'Indonezija',
        'IE'=>'Irska',
        'IL'=>'Izrael',
        'IM'=>'Ostrvo čoveka',
        'IN'=>'Indija',
        'IO'=>'Britanska teritorija Indijskog okeana',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Island',
        'IT'=>'Italija',
        'JE'=>'Džerzi',
        'JM'=>'Jamajka',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenija',
        'KG'=>'Kirgistan',
        'KH'=>'Kambodža',
        'KI'=>'Kiribati',
        'KM'=>'Komori',
        'KN'=>'Sent Kits i Nevis',
        'KR'=>'Koreja (Republika)',
        'KW'=>'Kuvajt',
        'KY'=>'Kajmanska ostrva',
        'KZ'=>'Kazahstan',
        'LA'=>'Laoska Narodna Demokratska Republika',
        'LB'=>'Lebanon',
        'LC'=>'Sveta Lucija',
        'LI'=>'Lihtenštajn',
        'LK'=>'Šri Lanka',
        'LR'=>'Liberija',
        'LS'=>'Lesoto',
        'LT'=>'Litvanija',
        'LU'=>'Luksemburg',
        'LV'=>'Letonija',
        'LY'=>'Libijska Arapska Džamahirija',
        'MA'=>'Maroko',
        'MC'=>'Monako',
        'MD'=>'Moldavija (Republika)',
        'ME'=>'Crna gora',
        'MG'=>'Madagaskar',
        'MH'=>'Maršalska ostrva',
        'MK'=>'Makedonija, Bivša Jugoslovenska republika',
        'ML'=>'Mali',
        'MM'=>'Mijanmar',
        'MN'=>'Mongolija',
        'MO'=>'Makao',
        'MP'=>'Severna Marijanska ostrva',
        'MQ'=>'Martinik',
        'MR'=>'Mauritanija',
        'MS'=>'Monserat',
        'MT'=>'Malta',
        'MU'=>'Mauricijus',
        'MV'=>'Maldivi',
        'MW'=>'Malavi',
        'MX'=>'Meksiko',
        'MY'=>'Malezija',
        'MZ'=>'Mozambik',
        'NA'=>'Namibija',
        'NC'=>'Nova Kaledonija',
        'NE'=>'Niger',
        'NF'=>'Norfolska ostrva',
        'NG'=>'Nigerija',
        'NI'=>'Nikaragva',
        'NL'=>'Holandija',
        'NO'=>'Norveška',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Nijue',
        'NZ'=>'Novi Zeland',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Francuska Polinezija',
        'PG'=>'Papua Nova Gvineja',
        'PH'=>'Filipini',
        'PK'=>'Pakistan',
        'PL'=>'Poljska',
        'PM'=>'Sen Pjer i Mikelon',
        'PN'=>'Pitkern',
        'PR'=>'Portoriko',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paragvaj',
        'QA'=>'Katar',
        'RE'=>'Reunion',
        'RO'=>'Rumunija',
        'RS'=>'Srbija',
        'RU'=>'Rusija',
        'RW'=>'Ruanda',
        'SA'=>'Južna Arabija',
        'UK'=>'Škotska',
        'SB'=>'Solomonska ostrva',
        'SC'=>'Sejšeli',
        'SS'=>'Južni Sudan',
        'SD'=>'Sudan',
        'SE'=>'Švedska',
        'SG'=>'Singapur',
        'SH'=>'Sveta Helena',
        'SI'=>'Slovenija',
        'SJ'=>'Svalbard i Ostrva Jan Majen',
        'SK'=>'Slovačka',
        'SL'=>'Sijera Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalija',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome i Principe',
        'SU'=>'Sovjetski savez',
        'SV'=>'El Salvador',
        'SY'=>'Sirijska Arapska Republika',
        'SZ'=>'Svazilend',
        'TC'=>'Turks i Kajkos ostrva',
        'TD'=>'Čad',
        'TF'=>'Francuske južne zemlje',
        'TG'=>'Togo',
        'TH'=>'Tajland',
        'TJ'=>'Tadžikistan',
        'TK'=>'Tokelau',
        'TI'=>'Istočni Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunis',
        'TO'=>'Tonga',
        'TP'=>'Istočni Timor (stari kod)',
        'TR'=>'Turska',
        'TT'=>'Trinidad i Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Tajvan',
        'TZ'=>'Tanzanija',
        'UA'=>'Ukrajina',
        'UG'=>'Uganda',
        'UK'=>'Ujedinjeno Kraljevstvo',
        'US'=>'Sjedinjene države',
        'UM'=>'Mala spoljna ostrva Sjedinjenih Američkih Država',
        'UY'=>'Urugvaj',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatikan',
        'VC'=>'Sent Vinsent i Grenadini',
        'VE'=>'Venecuela',
        'VG'=>'Devičanska ostrva (Britanija)',
        'VI'=>'Devičanska ostrva (SAD)',
        'VN'=>'Vijetnam',
        'VU'=>'Vanuatu',
        'WF'=>'Ostrva Valis i Futuna',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Majot',
        'ZA'=>'Južna Afrika',
        'ZM'=>'Zambija',
        'ZW'=>'Zimbabve',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sr-CS/localizations.php <==
<?php

return [

    'select_language' => 'Izaberite jezik',
    'languages' => [
        'en-US'=> 'Engleski, SAD',
        'en-GB'=> 'Engleski, UK',
        'am-ET' => 'Amharski',
        'af-ZA'=> 'Afrički',
        'ar-SA'=> 'Arapski',
        'bg-BG'=> 'Bugarski',
        'zh-CN'=> 'Kineski pojednostavljen',
        'zh-TW'=> 'Kineski tradicionalan',
        'ca-ES' => 'Katalonski',
        'hr-HR'=> 'Hrvatski',
        'cs-CZ'=> 'Češki',
        'da-DK'=> 'Danski',
        'nl-NL'=> 'Holandski',
        'en-ID'=> 'Engleski, Indonezija',
        'et-EE'=> 'Estonski',
        'fil-PH'=> 'Filipinski',
        'fi-FI'=> 'Finski',
        'fr-FR'=> 'Francuski',
        'de-DE'=> 'Nemački',
        'de-if'=> 'Nemački (neformalni)',
        'el-GR'=> 'Grčki',
        'he-IL'=> 'Hebrejski',
        'hu-HU'=> 'Madjarski',
        'is-IS' => 'Islandski',
        'id-ID'=> 'Indonežanski',
        'ga-IE'=> 'Irski',
        'it-IT'=> 'Italijanski',
        'ja-JP'=> 'Japanski',
        'km-KH'=>'Kmer',
        'ko-KR'=> 'Korejski',
        'lt-LT'=>'Litvanski',
        'lv-LV'=> 'Letonski',
        'mk-MK'=> 'Makedonski',
        'ms-MY'=> 'Malajski',
        'mi-NZ'=> 'Maorski',
        'mn-MN'=> 'Mongolski',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norveški Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persijski',
        'pl-PL'=> 'Poljski',
        'pt-PT'=> 'Portugalski',
        'pt-BR'=> 'Portugalski (Brazil)',
        'ro-RO'=> 'Rumunski',
        'ru-RU'=> 'Ruski',
        'sr-CS' => 'Srpski (Latinica)',
        'sk-SK'=> 'Slovački',
        'sl-SI'=> 'Slovenački',
        'so-SO'=> 'Somalski',
        'es-ES'=> 'Španski',
        'es-CO'=> 'Španski (Kolumbija)',
        'es-MX'=> 'Španski (Meksiko)',
        'es-VE'=> 'Španski (Venecuela)',
        'sv-SE'=> 'Švedski',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamilski',
        'th-TH'=> 'Tajlandski',
        'tr-TR'=> 'Turski',
        'uk-UA'=> 'Ukrajinski',
        'vi-VN'=> 'Vijetnamski',
        'cy-GB'=> 'Velški',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Izaberite državu',
    
    'countries' => [
        'AC'=>'Asension',
        'AD'=>'Andora',
        'AE'=>'Ujedinjeni Arapski Emirati',
        'AF'=>'Afganistan',
        'AG'=>'Antigva i Barbuda',
        'AI'=>'Angvila',
        'AL'=>'Albanija',
        'AM'=>'Jermenija',
        'AN'=>'Holandski Antili',
        'AO'=>'Angola',
        'AQ'=>'Antartika',
        'AR'=>'Argentina',
        'AS'=>'Američka Samoa',
        'AT'=>'Austrija',
        'AU'=>'Australija',
        'AW'=>'Aruba',
        'AX'=>'Olandska Ostrva',
        'AZ'=>'Azerbejdžan',
        'BA'=>'Bosna i Hercegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgija',
        'BD'=>'Bangladeš',
        'BF'=>'Burkina Faso',
        'BG'=>'Bugarska',
        'BH'=>'Bahrein',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Bruneja Darusalam',
        'BO'=>'Bolivija',
        'BR'=>'Brazil',
        'BS'=>'Bahami',
        'BT'=>'Butan',
        'BV'=>'Ostrvo Buve',
        'BW'=>'Bocvana',
        'BY'=>'Belorusija',
        'BZ'=>'Beliz',
        'CA'=>'Kanada',
        'CC'=>'Kokosova (Kiling) Ostrva',
        'CD'=>'Kongo (Demokratska republika)',
        'CF'=>'Centralnoafrička Republika',
        'CG'=>'Kongo (Republika)',
        'CH'=>'Švajcarska',
        'CI'=>'Obala slonovače',
        'CK'=>'Kukova ostrva',
        'CL'=>'Čile',
        'CM'=>'Kamerun',
        'CN'=>'Narodna republika Kina',
        'CO'=>'Kolumbija',
        'CR'=>'Kostarika',
        'CU'=>'Kuba',
        'CV'=>'Zelenortska ostrva',
        'CX'=>'Božićno ostrvo',
        'CY'=>'Kipar',
        'CZ'=>'Češka republika',
        'DE'=>'Nemačka',
        'DJ'=>'Đibuti',
        'DK'=>'Danska',
        'DM'=>'Dominika',
        'DO'=>'Dominikanska republika',
        'DZ'=>'Alžir',
        'EC'=>'Ekvador',
        'EE'=>'Estonija',
        'EG'=>'Egipat',
        'GB-ENG'=>'Engleska',
        'ER'=>'Eritreja',
        'ES'=>'Španija',
        'ET'=>'Etiopija',
        'EU'=>'Evropska unija',
        'FI'=>'Finska',
        'FJ'=>'Fidži',
        'FK'=>'Folklanska ostrva',
        'FM'=>'Mikronezija',
        'FO'=>'Farska ostrva',
        'FR'=>'Francuska',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Gruzija',
        'GF'=>'Francuska gvajana',
        'GG'=>'Gernzi',
        'GH'=>'Gana',
        'GI'=>'Gibraltar',
        'GL'=>'Grenland',
        'GM'=>'Gambija',
        'GN'=>'Gvineja',
        'GP'=>'Gvadalupe',
        'GQ'=>'Ekvatorijalna gvineja',
        'GR'=>'Grčka',
        'GS'=>'Južna Džordžija i Južna Sendvič Ostrva',
        'GT'=>'Gvatemala',
        'GU'=>'Guam',
        'GW'=>'Gvineja Bisao',
        'GY'=>'Gvajana',
        'HK'=>'Hong Kong',
        'HM'=>'Ostrvo Herd i ostrva Makdonald',
        'HN'=>'Honduras',
        'HR'=>'Hrvatska',
        'HT'=>'Haiti',
        'HU'=>'Mađarska',
        'ID'=>'Indonezija',
        'IE'=>'Irska',
        'IL'=>'Izrael',
        'IM'=>'Ostrvo čoveka',
        'IN'=>'Indija',
        'IO'=>'Britanska teritorija Indijskog okeana',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Island',
        'IT'=>'Italija',
        'JE'=>'Džerzi',
        'JM'=>'Jamajka',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenija',
        'KG'=>'Kirgistan',
        'KH'=>'Kambodža',
        'KI'=>'Kiribati',
        'KM'=>'Komori',
        'KN'=>'Sent Kits i Nevis',
        'KR'=>'Koreja (Republika)',
        'KW'=>'Kuvajt',
        'KY'=>'Kajmanska ostrva',
        'KZ'=>'Kazahstan',
        'LA'=>'Laoska Narodna Demokratska Republika',
        'LB'=>'Lebanon',
        'LC'=>'Sveta Lucija',
        'LI'=>'Lihtenštajn',
        'LK'=>'Šri Lanka',
        'LR'=>'Liberija',
        'LS'=>'Lesoto',
        'LT'=>'Litvanija',
        'LU'=>'Luksemburg',
        'LV'=>'Letonija',
        'LY'=>'Libijska Arapska Džamahirija',
        'MA'=>'Maroko',
        'MC'=>'Monako',
        'MD'=>'Moldavija (Republika)',
        'ME'=>'Crna gora',
        'MG'=>'Madagaskar',
        'MH'=>'Maršalska ostrva',
        'MK'=>'Makedonija, Bivša Jugoslovenska republika',
        'ML'=>'Mali',
        'MM'=>'Mijanmar',
        'MN'=>'Mongolija',
        'MO'=>'Makao',
        'MP'=>'Severna Marijanska ostrva',
        'MQ'=>'Martinik',
        'MR'=>'Mauritanija',
        'MS'=>'Monserat',
        'MT'=>'Malta',
        'MU'=>'Mauricijus',
        'MV'=>'Maldivi',
        'MW'=>'Malavi',
        'MX'=>'Meksiko',
        'MY'=>'Malezija',
        'MZ'=>'Mozambik',
        'NA'=>'Namibija',
        'NC'=>'Nova Kaledonija',
        'NE'=>'Niger',
        'NF'=>'Norfolska ostrva',
        'NG'=>'Nigerija',
        'NI'=>'Nikaragva',
        'NL'=>'Holandija',
        'GB-NIR' => 'Severna Irska',
        'NO'=>'Norveška',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Nijue',
        'NZ'=>'Novi Zeland',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Francuska Polinezija',
        'PG'=>'Papua Nova Gvineja',
        'PH'=>'Filipini',
        'PK'=>'Pakistan',
        'PL'=>'Poljska',
        'PM'=>'Sen Pjer i Mikelon',
        'PN'=>'Pitkern',
        'PR'=>'Portoriko',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paragvaj',
        'QA'=>'Katar',
        'RE'=>'Reunion',
        'RO'=>'Rumunija',
        'RS'=>'Srbija',
        'RU'=>'Rusija',
        'RW'=>'Ruanda',
        'SA'=>'Južna Arabija',
        'GB-SCT'=>'Škotska',
        'SB'=>'Solomonska ostrva',
        'SC'=>'Sejšeli',
        'SS'=>'Južni Sudan',
        'SD'=>'Sudan',
        'SE'=>'Švedska',
        'SG'=>'Singapur',
        'SH'=>'Sveta Helena',
        'SI'=>'Slovenija',
        'SJ'=>'Svalbard i Ostrva Jan Majen',
        'SK'=>'Slovačka',
        'SL'=>'Sijera Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalija',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome i Principe',
        'SU'=>'Sovjetski savez',
        'SV'=>'El Salvador',
        'SY'=>'Sirijska Arapska Republika',
        'SZ'=>'Svazilend',
        'TC'=>'Turks i Kajkos ostrva',
        'TD'=>'Čad',
        'TF'=>'Francuske južne zemlje',
        'TG'=>'Togo',
        'TH'=>'Tajland',
        'TJ'=>'Tadžikistan',
        'TK'=>'Tokelau',
        'TI'=>'Istočni Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunis',
        'TO'=>'Tonga',
        'TP'=>'Istočni Timor (stari kod)',
        'TR'=>'Turska',
        'TT'=>'Trinidad i Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Tajvan',
        'TZ'=>'Tanzanija',
        'UA'=>'Ukrajina',
        'UG'=>'Uganda',
        'UK'=>'Ujedinjeno Kraljevstvo',
        'US'=>'Sjedinjene države',
        'UM'=>'Mala spoljna ostrva Sjedinjenih Američkih Država',
        'UY'=>'Urugvaj',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatikan',
        'VC'=>'Sent Vinsent i Grenadini',
        'VE'=>'Venecuela',
        'VG'=>'Devičanska ostrva (Britanija)',
        'VI'=>'Devičanska ostrva (SAD)',
        'VN'=>'Vijetnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Vels',
        'WF'=>'Ostrva Valis i Futuna',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Majot',
        'ZA'=>'Južna Afrika',
        'ZM'=>'Zambija',
        'ZW'=>'Zimbabve',
    ],
];
